@@ -235,6 +235,10 @@ def main(args=None):
     else:
         g = Github()
 
+    headers = {}
+    if args.github_access_token:
+        headers = {"Authorization": f"token {args.github_access_token}"}
+
     # Get GitHub Repository
     git = Repo(search_parent_directories=True)
     if args.repo:
